@@ -1,5 +1,5 @@
 package Net::Google::Analytics::AccountFeed;
-our $VERSION = '0.09999_01';
+our $VERSION = '0.10000';
 use strict;
 
 use base qw(Net::Google::Analytics::Feed);
@@ -51,5 +51,17 @@ Creates and returns a L<Net::Google::Analytics::FeedRequest> object.
 Retrieves the account feed. Returns a
 L<Net::Google::Analytics::AccountFeedResponse> object.
 
+=head1 AUTHOR
+
+Nick Wellnhofer <wellnhofer@aevum.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) Nick Wellnhofer, 2010
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.0 or,
+at your option, any later version of Perl 5 you may have available.
+
 =cut
 
