@@ -1,5 +1,5 @@
 package Net::Google::Analytics::AccountFeedResponse;
-our $VERSION = '0.09999_01';
+our $VERSION = '0.10000';
 use strict;
 
 use base qw(Net::Google::Analytics::FeedResponse);
@@ -35,5 +35,17 @@ See
 L<http://code.google.com/apis/analytics/docs/gdata/gdataReferenceAccountFeed.html#accountResponse>
 for a complete reference.
 
+=head1 AUTHOR
+
+Nick Wellnhofer <wellnhofer@aevum.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) Nick Wellnhofer, 2010
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.0 or,
+at your option, any later version of Perl 5 you may have available.
+
 =cut
 
