@@ -1,5 +1,5 @@
 package Net::Google::Analytics::DataFeedEntry;
-our $VERSION = '0.09999_01';
+our $VERSION = '0.10000';
 use strict;
 
 use base qw(Class::Accessor Net::Google::Analytics::XML);
@@ -53,5 +53,17 @@ An arrayref of L<Net::Google::Analytics::Dimension> objects.
 
 An arrayref of L<Net::Google::Analytics::Metric> objects.
 
+=head1 AUTHOR
+
+Nick Wellnhofer <wellnhofer@aevum.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) Nick Wellnhofer, 2010
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.0 or,
+at your option, any later version of Perl 5 you may have available.
+
 =cut
 
